/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import fetch from "isomorphic-fetch";
import { authRequestWithRetry } from "./odspAuth.js";
/**
 * @internal
 */
export async function getAsync(url, authRequestInfo) {
    return authRequest(authRequestInfo, async (config) => fetch(url, config));
}
/**
 * @internal
 */
export async function putAsync(url, authRequestInfo) {
    return authRequest(authRequestInfo, async (config) => {
        const putConfig = {
            ...config,
            method: "PUT",
        };
        return fetch(url, putConfig);
    });
}
/**
 * @internal
 */
export async function postAsync(url, body, authRequestInfo) {
    return authRequest(authRequestInfo, async (config) => {
        const postConfig = {
            ...config,
            body,
            method: "POST",
        };
        return fetch(url, postConfig);
    });
}
/**
 * @internal
 */
export async function unauthPostAsync(url, body) {
    return safeRequestCore(async () => {
        return fetch(url, { body, method: "POST" });
    });
}
async function authRequest(authRequestInfo, requestCallback) {
    return authRequestWithRetry(authRequestInfo, async (config) => safeRequestCore(async () => requestCallback(config)));
}
async function safeRequestCore(requestCallback) {
    let response;
    try {
        response = await requestCallback();
    }
    catch (error) {
        if (error?.response?.status) {
            response = error.response;
        }
        else {
            throw error;
        }
    }
    return response;
}
//# sourceMappingURL=odspRequest.js.map